@@ -848,7 +848,7 @@ static double MT_genrand(void)
 */
 
 
-#define long Int32
+//#define long Int32
 #define ran_arr_buf       R_KT_ran_arr_buf
 #define ran_arr_cycle     R_KT_ran_arr_cycle
 #define ran_arr_ptr       R_KT_ran_arr_ptr
